@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Protocol
+from typing import Optional, Protocol
 
 
 class HealthStatus(Enum):
@@ -9,11 +9,14 @@ class HealthStatus(Enum):
 
 class HealthCheckResult:
     status: HealthStatus
-    description: str
-    exception: Exception
+    description: Optional[str]
+    exception: Optional[Exception]
 
     def __init__(
-        self, status: HealthStatus, description: str = None, exception: Exception = None
+        self,
+        status: HealthStatus,
+        description: Optional[str] = None,
+        exception: Optional[Exception] = None,
     ) -> None:
         if exception is not None:
             assert status == HealthStatus.UNHEALTHY
